@@ -43,9 +43,13 @@ def render_activity(activity, *args, **kwargs):
     """
     template_name = 'activity_monitor/includes/models/{0.app_label}_{0.model}.html'.format(activity.content_type)
     try:
-        return loader.get_template(template_name).render(Context({'activity': activity}))
+        tmpl = loader.get_template(template_name)
     except template.TemplateDoesNotExist:
         return None
+    # we know we have a template, so render it
+    content_object = activity.content_object
+    return tmpl.render(Context({'activity': activity, 'obj': content_object}))
+
 
 
 
@@ -83,9 +87,9 @@ def show_new_activity(last_seen=None, cap=1000, template='grouped'):
     If no template choice argument is passed, 
 
     """
-    if not last_seen:
-        last_seen = datetime.date.today()
-    activities = Activity.objects.filter(timestamp__gte=last_seen)[:cap]
+    if not last_seen or last_seen is '':
+        activity_last_seen = datetime.date.today()
+    activities = Activity.objects.filter(timestamp__gte=activity_last_seen)[:cap]
 
     if template=='detailed':
         template = 'activity_monitor/includes/detailed.html'
